==> jc-1.4.0.tar.gz: javax/print/attribute/DateTimeSyntax.h <==
// public abstract class javax.print.attribute.DateTimeSyntax

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 7f661930fc2aa0c5 javax_print_attribute_DateTimeSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_DateTimeSyntax_H_
#define _JC_javax_print_attribute_DateTimeSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_javax_print_attribute_DateTimeSyntax$sub_refs	_jc_javax_print_attribute_DateTimeSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs	_jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$refs	_jc_javax_print_attribute_DateTimeSyntax$refs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$nonrefs	_jc_javax_print_attribute_DateTimeSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$object	_jc_javax_print_attribute_DateTimeSyntax$object;

typedef struct _jc_javax_print_attribute_DateTimeSyntax$fields_struct	_jc_javax_print_attribute_DateTimeSyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_DateTimeSyntax$vmethods	_jc_javax_print_attribute_DateTimeSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_DateTimeSyntax$vtable	_jc_javax_print_attribute_DateTimeSyntax$vtable;
typedef const struct _jc_javax_print_attribute_DateTimeSyntax$vtype	_jc_javax_print_attribute_DateTimeSyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_DateTimeSyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_DateTimeSyntax$fields_struct _jc_javax_print_attribute_DateTimeSyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_DateTimeSyntax$method$_init$7de091b6eaf74c19(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *, struct _jc_java_util_Date$object *);

// Virtual methods
extern jboolean _jc_javax_print_attribute_DateTimeSyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_util_Date$object *_jc_javax_print_attribute_DateTimeSyntax$method$getValue$24fc2c1799268f30(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *);
extern jint _jc_javax_print_attribute_DateTimeSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_DateTimeSyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_DateTimeSyntax$method_info$getValue$24fc2c1799268f30;
extern _jc_method _jc_javax_print_attribute_DateTimeSyntax$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_print_attribute_DateTimeSyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_util_Date$object	*(*getValue$24fc2c1799268f30)(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *);
};

// Vtable
struct _jc_javax_print_attribute_DateTimeSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_DateTimeSyntax$vmethods	javax_print_attribute_DateTimeSyntax;
};

// Vtype
struct _jc_javax_print_attribute_DateTimeSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_DateTimeSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_DateTimeSyntax$sub_refs {
	struct _jc_java_util_Date$object	*value;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_DateTimeSyntax$refs {
    _jc_javax_print_attribute_DateTimeSyntax$sub_refs	javax_print_attribute_DateTimeSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_DateTimeSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs	javax_print_attribute_DateTimeSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_DateTimeSyntax$object {
	_jc_javax_print_attribute_DateTimeSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_DateTimeSyntax$vtype	*vtype;
	_jc_javax_print_attribute_DateTimeSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_DateTimeSyntax$vtype _jc_javax_print_attribute_DateTimeSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_DateTimeSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_DateTimeSyntax$class_object;

#endif	/* _JC_javax_print_attribute_DateTimeSyntax_H_ */

==> jc-1.4.6.tar.gz: javax/print/attribute/DateTimeSyntax.h <==
// public abstract class javax.print.attribute.DateTimeSyntax

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 7f661930fc2aa0c5 javax_print_attribute_DateTimeSyntax

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_print_attribute_DateTimeSyntax_H_
#define _JC_javax_print_attribute_DateTimeSyntax_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Date$object;

// Typedefs
typedef struct _jc_javax_print_attribute_DateTimeSyntax$sub_refs	_jc_javax_print_attribute_DateTimeSyntax$sub_refs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs	_jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$refs	_jc_javax_print_attribute_DateTimeSyntax$refs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$nonrefs	_jc_javax_print_attribute_DateTimeSyntax$nonrefs;
typedef struct _jc_javax_print_attribute_DateTimeSyntax$object	_jc_javax_print_attribute_DateTimeSyntax$object;

typedef struct _jc_javax_print_attribute_DateTimeSyntax$fields_struct	_jc_javax_print_attribute_DateTimeSyntax$fields_struct;
typedef const struct _jc_javax_print_attribute_DateTimeSyntax$vmethods	_jc_javax_print_attribute_DateTimeSyntax$vmethods;
typedef const struct _jc_javax_print_attribute_DateTimeSyntax$vtable	_jc_javax_print_attribute_DateTimeSyntax$vtable;
typedef const struct _jc_javax_print_attribute_DateTimeSyntax$vtype	_jc_javax_print_attribute_DateTimeSyntax$vtype;

// Class fields structure
struct _jc_javax_print_attribute_DateTimeSyntax$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_print_attribute_DateTimeSyntax$fields_struct _jc_javax_print_attribute_DateTimeSyntax$class_fields;

// Constructors
extern void _jc_javax_print_attribute_DateTimeSyntax$method$_init$7de091b6eaf74c19(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *, struct _jc_java_util_Date$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_print_attribute_DateTimeSyntax$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_Date$object *_jc_javax_print_attribute_DateTimeSyntax$method$getValue$24fc2c1799268f30(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_print_attribute_DateTimeSyntax$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_print_attribute_DateTimeSyntax$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_print_attribute_DateTimeSyntax$method_info$getValue$24fc2c1799268f30;
extern _jc_method _jc_javax_print_attribute_DateTimeSyntax$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_print_attribute_DateTimeSyntax$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_Date$object	*(*getValue$24fc2c1799268f30)(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_print_attribute_DateTimeSyntax$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_print_attribute_DateTimeSyntax$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_print_attribute_DateTimeSyntax$vmethods	javax_print_attribute_DateTimeSyntax;
};

// Vtype
struct _jc_javax_print_attribute_DateTimeSyntax$vtype {
	_jc_type			type;
	_jc_javax_print_attribute_DateTimeSyntax$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_attribute_DateTimeSyntax$sub_refs {
	struct _jc_java_util_Date$object	*value;
};

// Reference instance fields (object)
struct _jc_javax_print_attribute_DateTimeSyntax$refs {
    _jc_javax_print_attribute_DateTimeSyntax$sub_refs	javax_print_attribute_DateTimeSyntax;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_attribute_DateTimeSyntax$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_print_attribute_DateTimeSyntax$sub_nonrefs	javax_print_attribute_DateTimeSyntax;
};

// Object instance structure
struct _jc_javax_print_attribute_DateTimeSyntax$object {
	_jc_javax_print_attribute_DateTimeSyntax$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_attribute_DateTimeSyntax$vtype	*vtype;
	_jc_javax_print_attribute_DateTimeSyntax$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_attribute_DateTimeSyntax$vtype _jc_javax_print_attribute_DateTimeSyntax$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_attribute_DateTimeSyntax, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_attribute_DateTimeSyntax$class_object;

#endif	/* _JC_javax_print_attribute_DateTimeSyntax_H_ */
